History
=======

0.5.1 (26-09-2014)
------------------

- If only one url is specified, don't pass a list to rawes, but a string. This
  allows rawes to autodetect paths. (#2)

0.5.0 (27-08-2014)
------------------

- Switch to py.test for unit tests.
- Add ability to specify several ES hosts in the url setting.

0.4.1 (15-04-2014)
------------------

- Restore compatibility with zope.interface 4.1.x
- Add Coveralls

0.4.0 (27-09-2013)
------------------

- Make pyramid_rawes compatible with rawes 0.5.x
- Introduce unit test support for py3k (requires rawes 0.5.1)
- Ability to specify json_encoder and json_decoder as dotted python name.
- Dropped support for py26.

0.3.0 (29-04-2013)
------------------

- Make pyramid_rawes compatible with rawes 0.4.0.

0.2.1 (24-04-2013)
------------------

- Fixed dependency on rawes < 0.4.0. Next release will upgrade to rawes 0.4.0.

0.2.0 (18-01-2013)
------------------

- Added get_rawes as a config directive
- Renamed IRawES to IRawes
- Pep8 fixes

0.1.0 (16-01-2013)
------------------

- Initial version
